@@ -37,10 +37,17 @@ def test_vectors():
         assert p1.data.shape == grid.shape
         np.testing.assert_allclose(p1.data, value)
 
-    v2 = FieldBase.from_state(v1.state_serialized, grid=grid, data=v1.data)
+    v2 = FieldBase.from_state(v1.attributes, data=v1.data)
     assert v1 == v2
+    assert v1.grid is v2.grid
+    
+    attrs = VectorField.unserialize_attributes(v1.attributes_serialized)
+    v2 = FieldBase.from_state(attrs, data=v1.data)
+    assert v1 == v2
+    assert v1.grid is not v2.grid
 
     # test dot product
+    v2._grid = v1.grid  # make sure grids are identical
     v1.data = 1
     v2.data = 2
     for s in (v1 @ v2, v2 @ v1, v1.dot(v2)):
@@ -122,6 +129,9 @@ def test_from_expressions():
     ys = grid.cell_coords[..., 1]
     np.testing.assert_allclose(vf.data[0], xs**2)
     np.testing.assert_allclose(vf.data[1], xs * ys)
+
+    # corner case
+    vf = VectorField.from_expression(grid, ['1', 'x * y'])
     
     with pytest.raises(ValueError):
         VectorField.from_expression(grid, 'xy')
@@ -131,4 +141,11 @@ def test_from_expressions():
         VectorField.from_expression(grid, ['x'] * 3)
         
         
+
+def test_vector_plot_quiver_reduction():
+    """ test whether quiver plots reduce the resolution """
+    grid = UnitGrid([6, 6])
+    field = VectorField.random_normal(grid)
+    res = field.plot(method='quiver', max_points=4)
+    assert len(res.U) == 16
         
\ No newline at end of file
