@@ -8,12 +8,14 @@ Bases classes
 import json
 import functools
 import logging
+import inspect
 from abc import ABCMeta, abstractmethod, abstractproperty
 from typing import (List, Tuple, Dict, Any, Union, Callable, Generator,
-                    Sequence, TYPE_CHECKING)
+                    Sequence, Set, TYPE_CHECKING)
 
 import numpy as np
 
+from ..tools.misc import classproperty
 from ..tools.numba import jit
 from ..tools.cache import cached_property, cached_method
 from ..tools.docstrings import fill_in_docstring
@@ -98,37 +100,20 @@ class PeriodicityError(RuntimeError):
 
 
 class GridBase(metaclass=ABCMeta):
-    """ Base class for all grids defining common methods and interfaces
-    
-    Attributes:
-        dim (int):
-            The spatial dimension in which the grid is embedded
-        shape (tuple):
-            The number of support points in each axis. Note that `len(shape)`
-            might be smaller than `dim` if the grid assumes some symmetry. For
-            instance, a spherically symmetric grid has `dim == 3`, but
-            `len(shape) == 1`.
-        discretization (:class:`numpy.ndarray`):
-            The discretization along each axis.
-        axes (tuple):
-            The name of all the axes that are described by the grid.
-        axes_symmetric (tuple):
-            The names of the additional axes that the fields do not depend on,
-            e.g. along which they are constant.
-        axes_coords (tuple):
-            The discretization points along each axis
-        axes_bounds (tuple):
-            The coordinate bounds of each axes
-    """
+    """ Base class for all grids defining common methods and interfaces """
     
     _subclasses: Dict[str, 'GridBase'] = {}  # all classes inheriting from this
+    _operators: Dict[str, Callable] = {}  # all operators defined for the grid
     
     # properties that are defined in subclasses
-    axes: List[str]
+    dim: int  # int: The spatial dimension in which the grid is embedded
+    axes: List[str]  # list: Name of all axes that are described by the grid
     axes_symmetric: List[str] = []
+    """ list: The names of the additional axes that the fields do not depend on,
+    e.g. along which they are constant. """
+
     cell_volume_data: Sequence[Union[float, np.ndarray]]
     coordinate_constraints: List[int] = []  # axes not described explicitly
-    dim: int
     num_axes: int
     periodic: List[bool]
 
@@ -148,6 +133,7 @@ class GridBase(metaclass=ABCMeta):
         """ register all subclassess to reconstruct them later """
         super().__init_subclass__(**kwargs)
         cls._subclasses[cls.__name__] = cls
+        cls._operators: Dict[str, Callable] = {}
 
 
     @classmethod
@@ -314,15 +300,79 @@ class GridBase(metaclass=ABCMeta):
     @abstractmethod
     def get_boundary_conditions(self, bc='natural') -> "Boundaries": pass
     @abstractmethod
-    def get_operator(self, op, bc): pass
-    @abstractmethod
     def get_line_data(self, data, extract: str = 'auto'): pass
     @abstractmethod
     def get_image_data(self, data): pass
     @abstractmethod
     def get_random_point(self, boundary_distance: float = 0,
                          cartesian: bool = True): pass
+
+    
+    @classmethod
+    def register_operator(cls, name: str, factory_func: Callable):
+        """ register an operator for this class
+        
+        Args:
+            name (str):
+                The name of the operator to register
+            factory_func (callable):
+                A function with signature ``(bcs: Boundaries, **kwargs)``, which
+                takes boundary conditions and optional keyword arguments and
+                returns an implementation of the given operator.
+        """
+        cls._operators[name] = factory_func
              
+             
+    @classproperty
+    def operators(cls) -> Set[str]:  # @NoSelf
+        """ set: all operators defined for this class """
+        result = set()
+        classes = inspect.getmro(cls)[:-1]  # type: ignore
+        for anycls in classes:
+            result |= set(anycls._operators.keys())  # type: ignore
+        return result
+            
+
+    @cached_method()
+    @fill_in_docstring
+    def get_operator(self, name: str,
+                     bc: "Boundaries",
+                     **kwargs) -> Callable:
+        """ return a discretized operator defined on this grid
+         
+        Args:
+            name (str):
+                Identifier for the operator. Some examples are 'laplace',
+                'gradient', or 'divergence'. The registered operators for this
+                grid can be obtained from the
+                :attr:`~pde.grids.base.GridBase.operators` attribute.
+            bc (str or list or tuple or dict):
+                The boundary conditions applied to the field.
+                {ARG_BOUNDARIES}  
+            **kwargs:
+                Specifies extra arguments that can influence how the operator
+                is created. Many operators support a `method` argument that can
+                typically be set to 'numba', 'scipy', or `auto`.
+                 
+        Returns:
+            A function that takes the discretized data as an input and returns
+            the data to which the operator `name` has been applied. This
+            function optionally supports a second argument, which provides
+            allocated memory for the output.
+        """
+        # obtain all parent classes, except `object`
+        classes = inspect.getmro(self.__class__)[:-1]
+        for cls in classes:
+            if name in cls._operators:  # type: ignore
+                bcs = self.get_boundary_conditions(bc)
+                return cls._operators[name](bcs, **kwargs)  # type: ignore
+            
+        # operator was not found
+        raise ValueError(f"'{name}' is not one of the defined operators: "
+                         f"{', '.join(sorted(self.operators))}. Custom "
+                         "operators can be added using the `register_operator` "
+                         "method.")
+            
 
     def get_subgrid(self, indices: Sequence[int]) -> "GridBase":
         """ return a subgrid of only the specified axes """
