@@ -19,7 +19,7 @@ from typing import Callable
 
 from scipy import sparse
 
-from .common import make_poisson_solver
+from .common import make_general_poisson_solver
 from .. import PolarGrid
 from ..boundaries import Boundaries
 from ...tools.numba import jit_allocate_out
@@ -323,6 +323,24 @@ def _get_laplace_matrix(bcs):
 
 
 
+@fill_in_docstring
+def make_poisson_solver(bcs: Boundaries, method: str = 'auto') -> Callable:
+    """ make a operator that solves Poisson's equation
+    
+    {DESCR_POLAR_GRID}
+
+    Args:
+        bcs (:class:`~pde.grids.boundaries.axes.Boundaries`):
+            {ARG_BOUNDARIES_INSTANCE}
+        
+    Returns:
+        A function that can be applied to an array of values
+    """
+    matrix, vector = _get_laplace_matrix(bcs)
+    return make_general_poisson_solver(matrix, vector, method)
+
+
+
 @fill_in_docstring
 def make_operator(op: str, bcs: Boundaries) -> Callable:
     """ make a discretized operator for a polar grid
@@ -352,11 +370,17 @@ def make_operator(op: str, bcs: Boundaries) -> Callable:
     elif op == 'tensor_divergence':
         return make_tensor_divergence(bcs)
     elif op == 'poisson_solver' or op == 'solve_poisson' or op == 'poisson':
-        return make_poisson_solver(*_get_laplace_matrix(bcs))
+        return make_general_poisson_solver(*_get_laplace_matrix(bcs))
     else:
         raise NotImplementedError(f'Operator `{op}` is not defined for '
                                   'polar grids')
         
         
+# register all operators with the grid class
+PolarGrid.register_operator('laplace', make_laplace)
+PolarGrid.register_operator('gradient', make_gradient)
+PolarGrid.register_operator('divergence', make_divergence)
+PolarGrid.register_operator('vector_gradient', make_vector_gradient)
+PolarGrid.register_operator('tensor_divergence', make_tensor_divergence)
+PolarGrid.register_operator('poisson_solver', make_poisson_solver)
 
-    
