@@ -103,3 +103,18 @@ def test_grid_plotting():
 
     grids.PolarGrid(4, 8).plot()
     grids.PolarGrid((2, 4), 8).plot()
+    
+    
+    
+def test_operators():
+    """ test operator mechanism """
+    def make_op(state):
+        return lambda state: state
+    for grid in iter_grids():
+        assert "laplace" in grid.operators
+        with pytest.raises(ValueError):
+            grid.get_operator('not_existent', 'natural')
+        grid.register_operator('noop', make_op)
+        assert "noop" in grid.operators
+        del grid._operators['noop']  # reset original state
+        
\ No newline at end of file
