@@ -2,12 +2,13 @@
 Handling mathematical expressions with sympy
 
 This module provides classes representing expressions that can be provided as 
-human-readable strings and are converted to numpy and numba representations
-using sympy.
+human-readable strings and are converted to :mod:`numpy` and :mod:`numba`
+representations using :mod:`sympy`.
 
 .. autosummary::
    :nosignatures:
 
+   parse_number
    ScalarExpression
    TensorExpression
    
@@ -34,15 +35,15 @@ from .numba import jit
 
 
 @fill_in_docstring
-def parse_number(expression: Union[str, Number],
-                 variables: Dict[str, Number] = None) -> float:
+def parse_number(expression: Union[str, float],
+                 variables: Dict[str, float] = None) -> float:
     r""" return a number compiled from an expression
     
     Warning:
         {WARNING_EXEC}
     
     Args:
-        expression (str or number):
+        expression (str or float):
             An expression that can be interpreted as a number
         variables (dict):
             A dictionary of values that replace variables in the expression
