@@ -126,7 +126,7 @@ class Parameterized():
     """ a mixin that manages the parameters of a class """
 
     parameters_default: Sequence[Parameter] = []
-    _subclasses: Dict[str, Any] = {}
+    _subclasses: Dict[str, 'Parameterized'] = {}
 
 
     def __init__(self, parameters: Dict[str, Any] = None,
@@ -136,7 +136,8 @@ class Parameterized():
         
         Args:
             parameters (dict):
-                A dictionary of parameters to change the defaults
+                A dictionary of parameters to change the defaults. Call
+                :meth:`~Parameterized.show_parameters` for details.
             check_validity (bool):
                 Determines whether a `ValueError` is raised if there are keys in
                 parameters that are not in the defaults. If `False`, additional
