@@ -7,7 +7,7 @@ export NUMBA_DISABLE_JIT=1
 export MPLBACKEND="agg"
 
 mkdir -p coverage
-python3 -m pytest  -n $CORES \
-     --durations=10 \
+python3 -m pytest -c pytest.ini -n $CORES \
+    --durations=10 \
 	--cov-report html:coverage \
 	--cov=pde ..
